[![ballet](https://img.shields.io/static/v1?label=built%20with&message=ballet&color=FCDD35)](https://github.com/HDI-Project/ballet)

# {{ cookiecutter.project_name }}

This is a collaborative predictive modeling project built on the [ballet framework](https://github.com/HDI-Project/ballet).
